@@ -1,15 +1,12 @@
 #line 1 "inc/ExtUtils/AutoInstall.pm - C:/perl5/site/lib/ExtUtils/AutoInstall.pm"
-# $File: //member/autrijus/ExtUtils-AutoInstall/lib/ExtUtils/AutoInstall.pm $ 
-# $Revision: #14 $ $Change: 10538 $ $DateTime: 2004/04/29 17:55:36 $ vim: expandtab shiftwidth=4
-
 package ExtUtils::AutoInstall;
-$ExtUtils::AutoInstall::VERSION = '0.61';
+$ExtUtils::AutoInstall::VERSION = '0.62';
 
 use strict;
 use Cwd ();
 use ExtUtils::MakeMaker ();
 
-#line 308
+#line 305
 
 # special map on pre-defined feature sets
 my %FeatureMap = (
@@ -357,8 +354,10 @@ sub _install_cpan {
     my %args;
 
     require CPAN; CPAN::Config->load;
+    require Config;
 
-    return unless _can_write(MM->catfile($CPAN::Config->{cpan_home}, 'sources'));
+    return unless _can_write(MM->catfile($CPAN::Config->{cpan_home}, 'sources'))
+              and _can_write($Config::Config{sitelib});
 
     # if we're root, set UNINST=1 to avoid trouble unless user asked for it.
     my $makeflags = $CPAN::Config->{make_install_arg} || '';
@@ -488,8 +487,7 @@ sub _can_write {
     my $path = shift;
     mkdir ($path, 0755) unless -e $path;
 
-    require Config;
-    return 1 if -w $path and -w $Config::Config{sitelib};
+    return 1 if -w $path;
 
     print << ".";
 *** You are not allowed to write to the directory '$path';
@@ -646,4 +644,4 @@ installdeps ::
 
 __END__
 
-#line 973
+#line 971
